package testcases::base;
use strict;
use warnings;

use base qw(XAO::testcases::base);

###############################################################################
1;
